emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r103988: Minor cleanup in src/xdisp.c


From: Eli Zaretskii
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r103988: Minor cleanup in src/xdisp.c.
Date: Sun, 24 Apr 2011 19:59:37 +0300
User-agent: Bazaar (2.3.1)

------------------------------------------------------------
revno: 103988
committer: Eli Zaretskii <address@hidden>
branch nick: trunk
timestamp: Sun 2011-04-24 19:59:37 +0300
message:
  Minor cleanup in src/xdisp.c.
  
   src/xdisp.c (handle_single_display_spec): Rename the
   display_replaced_before_p argument into display_replaced_p, to
   make it consistent with the commentary.  Fix typos in the
   commentary.
modified:
  src/ChangeLog
  src/xdisp.c
=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2011-04-24 16:28:57 +0000
+++ b/src/ChangeLog     2011-04-24 16:59:37 +0000
@@ -1,5 +1,10 @@
 2011-04-24  Eli Zaretskii  <address@hidden>
 
+       * xdisp.c (handle_single_display_spec): Rename the
+       display_replaced_before_p argument into display_replaced_p, to
+       make it consistent with the commentary.  Fix typos in the
+       commentary.
+
        * textprop.c (syms_of_textprop): Remove dead code.
        (copy_text_properties): Delete obsolete commentary about an
        interface that was deleted long ago.  Fix typos in the description

=== modified file 'src/xdisp.c'
--- a/src/xdisp.c       2011-04-23 10:33:28 +0000
+++ b/src/xdisp.c       2011-04-24 16:59:37 +0000
@@ -3855,7 +3855,7 @@
 }
 
 
 /* Set up IT from a single `display' specification PROP.  OBJECT
    is the object in which the `display' property was found.  *POSITION
    is the position at which it was found.  DISPLAY_REPLACED_P non-zero
    means that we previously saw a display specification which already
@@ -3865,7 +3865,7 @@
    OVERLAY is the overlay this `display' property came from,
    or nil if it was a text property.
 
-   If PROP is a `space' or `image' specification, and in some other
+   If SPEC is a `space' or `image' specification, and in some other
    cases too, set *POSITION to the position where the `display'
    property ends.
 
@@ -3875,7 +3875,7 @@
 static int
 handle_single_display_spec (struct it *it, Lisp_Object spec, Lisp_Object 
object,
                            Lisp_Object overlay, struct text_pos *position,
-                           int display_replaced_before_p)
+                           int display_replaced_p)
 {
   Lisp_Object form;
   Lisp_Object location, value;
@@ -4171,7 +4171,7 @@
 #endif /* not HAVE_WINDOW_SYSTEM */
              || (CONSP (value) && EQ (XCAR (value), Qspace)));
 
-  if (valid_p && !display_replaced_before_p)
+  if (valid_p && !display_replaced_p)
     {
       /* Save current settings of IT so that we can restore them
         when we are finished with the glyph property value.  */
@@ -3855,7 +3855,7 @@
 
 
-/* Set up IT from a single `display' specification PROP.  OBJECT
+/* Set up IT from a single `display' property specification SPEC.  OBJECT
    is the object in which the `display' property was found.  *POSITION
    is the position at which it was found.  DISPLAY_REPLACED_P non-zero


reply via email to

[Prev in Thread] Current Thread [Next in Thread]